==> humhub-1.4.2.tar.gz: humhub-1.4.2/protected/humhub/modules/ldap/messages/vi/base.php <==
<?php
return array (
  'A TLS/SSL is strongly favored in production environments to prevent passwords from be transmitted in clear text.' => '',
  'Base DN' => '',
  'Defines the filter to apply, when login is attempted. %s replaces the username in the login action. Example: &quot;(sAMAccountName=%s)&quot; or &quot;(uid=%s)&quot;' => '',
  'E-Mail Address Attribute' => '',
  'Enable LDAP Support' => '',
  'Encryption' => '',
  'Fetch/Update Users Automatically' => '',
  'Hostname' => 'Tên host',
  'ID Attribute' => '',
  'LDAP' => '',
  'LDAP Attribute for E-Mail Address. Default: &quotmail&quot;' => '',
  'LDAP Attribute for Username. Example: &quotuid&quot; or &quot;sAMAccountName&quot;' => '',
  'Limit access to users meeting this criteria. Example: &quot(objectClass=posixAccount)&quot; or &quot;(&(objectClass=person)(memberOf=CN=Workers,CN=Users,DC=myDomain,DC=com))&quot;' => '',
  'Login Filter' => '',
  'Not changeable LDAP attribute to unambiguously identify the user in the directory. If empty the user will be determined automatically by e-mail address or username. Examples: objectguid (ActiveDirectory) or uidNumber (OpenLDAP)' => '',
  'Password' => 'Mật khẩu',
  'Port' => '',
  'Specify your LDAP-backend used to fetch user accounts.' => '',
  'Status: Error! (Message: {message})' => '',
  'Status: OK! ({userCount} Users)' => '',
  'Status: Warning! (No users found using the ldap user filter!)' => '',
  'The default base DN used for searching for accounts.' => '',
  'The default credentials password (used only with username above).' => '',
  'The default credentials username. Some servers require that this be in DN form. This must be given in DN form if the LDAP server requires a DN to bind and binding should be possible with simple usernames.' => '',
  'User Filer' => '',
  'Username' => 'Tên truy cập',
  'Username Attribute' => '',
);

==> humhub-1.5.2.tar.gz: humhub-1.5.2/protected/humhub/modules/ldap/messages/vi/base.php <==
<?php
return array (
  'A TLS/SSL is strongly favored in production environments to prevent passwords from be transmitted in clear text.' => '',
  'Base DN' => '',
  'Defines the filter to apply, when login is attempted. %s replaces the username in the login action. Example: &quot;(sAMAccountName=%s)&quot; or &quot;(uid=%s)&quot;' => '',
  'E-Mail Address Attribute' => '',
  'Enable LDAP Support' => '',
  'Encryption' => 'Mã hóa',
  'Fetch/Update Users Automatically' => '',
  'Hostname' => 'Tên host',
  'ID Attribute' => '',
  'LDAP' => 'LDAP',
  'LDAP Attribute for E-Mail Address. Default: &quot;mail&quot;' => '',
  'LDAP Attribute for Username. Example: &quot;uid&quot; or &quot;sAMAccountName&quot;' => '',
  'Limit access to users meeting this criteria. Example: &quot;(objectClass=posixAccount)&quot; or &quot;(&(objectClass=person)(memberOf=CN=Workers,CN=Users,DC=myDomain,DC=com))&quot;' => '',
  'Login Filter' => '',
  'Not changeable LDAP attribute to unambiguously identify the user in the directory. If empty the user will be determined automatically by e-mail address or username. Examples: objectguid (ActiveDirectory) or uidNumber (OpenLDAP)' => '',
  'Password' => 'Mật khẩu',
  'Port' => 'Port',
  'Specify your LDAP-backend used to fetch user accounts.' => '',
  'Status: Error! (Message: {message})' => '',
  'Status: OK! ({userCount} Users)' => '',
  'Status: Warning! (No users found using the ldap user filter!)' => '',
  'The default base DN used for searching for accounts.' => '',
  'The default credentials password (used only with username above).' => '',
  'The default credentials username. Some servers require that this be in DN form. This must be given in DN form if the LDAP server requires a DN to bind and binding should be possible with simple usernames.' => '',
  'User Filer' => '',
  'Username' => 'Tên truy cập',
  'Username Attribute' => '',
);
